=============
Image Colours
=============

.. currentmodule:: pynsn
.. autosummary::
    :toctree: api/

    ImageColours
    Colour


ImageColours
-----------------------
.. autoclass:: pynsn.ImageColours
   :members:
   :inherited-members:
   :undoc-members:

Colour
--------------
.. autoclass:: pynsn.Colour
   :members:
   :inherited-members:

   .. automethod:: convert_hextriplet_to_rgb
   .. automethod:: convert_rgb_hextriplet
   .. autoattribute:: NAMED_COLOURS
      :annotation: Dict with known colour names and hextriplets

